@@ -8,8 +8,10 @@ from .views import (
 router = routers.DefaultRouter()
 router.register('asn', ASNViewSet)
 router.register('session', BGPSessionViewSet, 'session')
+router.register('bgpsession', BGPSessionViewSet, 'bgpsession')
 router.register('routing-policy', RoutingPolicyViewSet)
 router.register('peer-group', BGPPeerGroupViewSet, 'peergroup')
+router.register('bgppeergroup', BGPPeerGroupViewSet, 'bgppeergroup')
 router.register('community', CommunityViewSet)
 
 
