@@ -1,6 +1,7 @@
 from django.urls import reverse
 from django.db import models
 from django.core.validators import MaxValueValidator, MinValueValidator, RegexValidator
+from django.core.exceptions import FieldError
 from django.conf import settings
 
 from taggit.managers import TaggableManager
@@ -8,6 +9,7 @@ from taggit.managers import TaggableManager
 from utilities.choices import ChoiceSet
 from netbox.models import NetBoxModel
 from netbox.models.features import ChangeLoggingMixin
+from ipam.models import Prefix
 
 
 class ASNStatusChoices(ChoiceSet):
@@ -38,6 +40,14 @@ class SessionStatusChoices(ChoiceSet):
     )
 
 
+class ActionChoices(ChoiceSet):
+
+    CHOICES = [
+        ('permit', 'Permit', 'green'),
+        ('deny', 'Deny', 'red'),
+    ]
+
+
 class ASNGroup(ChangeLoggingMixin, models.Model):
     """
     """
@@ -306,3 +316,97 @@ class BGPSession(NetBoxModel):
 
     def get_absolute_url(self):
         return reverse('plugins:netbox_bgp:bgpsession', args=[self.pk])
+
+
+class RoutingPolicyRule(NetBoxModel):
+    routing_policy = models.ForeignKey(
+        to=RoutingPolicy,
+        on_delete=models.CASCADE,
+        related_name='rules'
+    )
+    index = models.PositiveIntegerField()
+    action = models.CharField(
+        max_length=30,
+        choices=ActionChoices
+    )
+    description = models.CharField(
+        max_length=500,
+        blank=True
+    )
+    match_community = models.ManyToManyField(
+        to=Community,
+        blank=True,
+        related_name='+'
+    )
+    match_ip = models.ManyToManyField(
+        to='ipam.Prefix',
+        blank=True,
+        related_name='+',
+    )
+    match_ip_cond = models.JSONField(
+        blank=True,
+        null=True,
+    )
+    match_custom = models.JSONField(
+        blank=True,
+        null=True,
+    )
+    set_actions = models.JSONField(
+        blank=True,
+        null=True,
+    )
+
+    class Meta:
+        ordering = ('routing_policy', 'index')
+        unique_together = ('routing_policy', 'index')
+
+    def __str__(self):
+        return f'{self.routing_policy}: Rule {self.index}'
+
+    def get_absolute_url(self):
+        return reverse('plugins:netbox_bgp:routingpolicyrule', args=[self.pk])
+
+    def get_action_color(self):
+        return ActionChoices.colors.get(self.action)      
+
+    def get_ip_conditions(self):
+        queryset = Prefix.objects.none()
+        if self.match_ip_cond and self.match_ip_cond != {}:
+            try:
+                queryset = Prefix.objects.filter(**self.match_ip_cond)
+            except FieldError:
+                pass
+        return queryset
+
+    def get_match_custom(self):
+        # some kind of ckeck?
+        result = {}
+        if self.match_custom:
+            result = self.match_custom
+        return result
+
+    @property
+    def match_statements(self):
+        result = {}
+        # add communities
+        result.update(
+            {'community': list(self.match_community.all().values_list('value', flat=True))}
+        )
+        result.update(
+            {'ip address': [str(prefix) for prefix in self.match_ip.all().values_list('prefix', flat=True)]}
+        )
+        matched_ip = self.get_ip_conditions()
+        result['ip address'].extend([str(prefix) for prefix in matched_ip.values_list('prefix', flat=True)])
+        custom_match = self.get_match_custom()
+        # update community from custom
+        result['community'].extend(custom_match.get('community', []))
+        result['ip address'].extend(custom_match.get('ip address', []))
+        # remove empty matches
+        result = {k: v for k, v in result.items() if v}
+        return result
+
+    @property
+    def set_statements(self):
+        if self.set_actions:
+            return self.set_actions
+        return {}
